# PyMoDAQ Plugins

PyMoDAQ, Modular Data Acquisition with Python, is a set of **python** modules used to perform automated measurements. 

This repository contains various hardware plugins compatible with PyMoDAQ

GitHub repo: https://github.com/CEMES-CNRS

Documentation: http://pymodaq.cnrs.fr/